/**
* ============================================
* File type: Theme Extra
* File provides: Smooth Scrolling on querying direct UrLs with anchor
*           es1: http://localhost/#contacts (Single Page)
*           es2: http://localhost/page/#contacts (Multi Pages)
*
* Suggested: .haccess for cleaner URLs
*
* @author: Matteo Montanari <matteo@italinux.com>
*
* TERMS OF USE
* Open source under the GPLv3 License.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software Foundation,
* Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
* ============================================
*/

$(function() {

    /**
    * @preserve
    * INIT Scrolling on URL
    */
    if ($(location).attr("hash")) {

        initScrollURL();
    }

    /**
    * @preserve
    * ============================================
    * EXTERNAL:
    *   Scrolling through Direct Url INTERNET
    *   Main sections listed
    *   with speed in milliseconds
    * ============================================
    */
    function initScrollURL() {

        var delayMsecs = 1e3; // (10 x 10 x 10) = 1000 = 1sec
        var speedFactor = 2.5; // + o - speed (play with decimals first)

        /**
        * @preserve
        * List of Handlers for Scrolling Direct
        * Add or Edit with new #wyp / new add-ons
        *
        * Customise with + offset
        * Add-ons have same config in blocks/jscript (internal scrolling)
        * Change Both!
        */
        var options = {
            'menu': { offset: 0 },
            'banner': { offset: 0 },
            'what-i-do': { offset: 0 },
            'fb-page-posts': { offset: 0 },
            'about-me': { offset: 0 },
            'adverts': { offset: 0 },
            'bookmarks': { offset: 0 },
            'my-skills': { offset: 5 },
            'curriculum-vitae': { offset: 0 },
                'curriculum-vitae-skills': { offset: 90 },
                'curriculum-vitae-resume': { offset: 90 },
            'portfolio': { offset: 0 },
            'my-works': { offset: 0 },
            'prices': { offset: 0 },
            'testimonials': { offset: 0 },
            'social-media': { offset: 0 },
            'contacts': { offset: 5 },
                'contacts-more': { offset: 90 },
                    'contacts-more-mobile': { offset: 90 },
                    'contacts-more-address': { offset: 90 },
                    'contacts-more-email': { offset: 90 },
            'footer': { offset: 0 },
        };

        /** ============================================
        *  default values do NOT touch BELOW this line.
        */
        var animDurationMsecsDefault = 1e3;
        var offsetDefault = 50;

        var thisConfig;
        var thisHandler;

        var thisHash = $(location).attr("hash").substring(1);
        var parentHash = thisHash.substr(0, thisHash.lastIndexOf("-"));

        var offset;

        var timer;

        // Loop through main Object
        if (thisHash in options) {
            thisConfig = options[thisHash];
        } else if (parentHash in options) {

            var thisParent = options[parentHash];
            var thisChild  = ((typeof thisParent !== 'undefined') && (typeof thisParent[thisHash] !== 'undefined')) ? thisParent[thisHash] : false;

                // create current config obj and its fallback                    
                thisConfig = (thisChild) ? thisChild : thisParent; 
        }

        // set Object Values
        if (thisConfig) {

            // get current handler or its fallback
            thisHandler = "#wyp-" + ($("#wyp-" + thisHash).length ? thisHash : parentHash);


            // detect handler if Any
            if ($(thisHandler).length) {

                // get handler Offset
                var thisHandlerOffset = $(thisHandler).first().offset().top;

                // calculate speed (animation)
                var animDurationMsecs = Math.ceil(thisHandlerOffset / speedFactor);

                var thisAnimDurationMsecs = (animDurationMsecs) ? animDurationMsecs : animDurationMsecsDefault;
                            var postOffset = (thisConfig.offset) ? thisConfig.offset : offsetDefault;

                // Scroll Animate
                clearTimeout(timer);

                timer = setTimeout(function() {
                    $("html, body").animate({
                        scrollTop: thisHandlerOffset - postOffset
                    }, thisAnimDurationMsecs, "swing");
                }, delayMsecs);
            }
        }
    }
});
